Page 122 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 122

Home

    The Sect (the Illuminati) had many adepts in Russia
    whom it taught to scoff at oaths; and they only took the
    oath of fidelity to the monarchy, that they might the
    more _ easily annihilate the Russian diadem. The

    Se ee re ae a

    The

    conspirators were headed by Genet, heretofore the agent
    for the cabinet of Versailles, but now become the agent
    of the Jacobins.*

    Weishaupt's followers in placing their members as tutors
    to the sons of the wealthy and powerful, especially to
    those who were likely to become rulers.

    When the time finally came for the overthrow of the
    Czar in 1917, the man the powerful elite in the United
    States chose to support had a venomous hatred toward
    God. This is the way Lenin himself expressed his hatred:

    Every religious idea, every idea of a god, even flirting
    with the idea of god is unutterable vileness of the most
    dangerous kind, disease of the most abominable kind.
    Millions of sins, filthy deeds, acts of violence and
    physical contagions are far less dangerous than the
    subtle, spiritual idea of a god decked out in the smartest
    "ideological" costumes.”

    That war against God is the main driving policy of
    Communism was explained by Aleksandr Solzhenitsyn:

    Within the philosophical system of Marx and Lenin,
    and at the heart of their psychology, hatred of God is the

    117

    Babylon's War Against God

    The influence of the Illuminati reached to the Czarist

    Court of the Romanoffs due to the success of